@@ -27,8 +27,10 @@
 #include "cc-color-common.h"
 #include "cc-color-profile.h"
 
-struct _CcColorProfilePrivate
+struct _CcColorProfile
 {
+  GtkListBoxRow parent_instance;
+
   GtkWidget   *box;
   CdDevice    *device;
   CdProfile   *profile;
@@ -63,19 +65,14 @@ static gchar *
 cc_color_profile_get_profile_date (CdProfile *profile)
 {
   gint64 created;
-  gchar *string = NULL;
-  GDateTime *dt = NULL;
+  g_autoptr(GDateTime) dt = NULL;
 
   /* get profile age */
   created = cd_profile_get_created (profile);
   if (created == 0)
-    goto out;
+    return NULL;
   dt = g_date_time_new_from_unix_utc (created);
-  string = g_date_time_format (dt, "%x");
-out:
-  if (dt != NULL)
-    g_date_time_unref (dt);
-  return string;
+  return g_date_time_format (dt, "%x");
 }
 
 static gchar *
@@ -181,41 +178,40 @@ out:
 static const gchar *
 cc_color_profile_get_warnings (CcColorProfile *color_profile)
 {
-  CcColorProfilePrivate *priv = color_profile->priv;
   const gchar *tooltip = NULL;
   const guint seconds_in_one_day = 60 * 60 * 24;
   gint num_days;
   guint threshold_days = 0;
 
   /* autogenerated printer defaults */
-  if (cd_device_get_kind (priv->device) == CD_DEVICE_KIND_PRINTER &&
-      cd_profile_get_filename (priv->profile) == NULL)
+  if (cd_device_get_kind (color_profile->device) == CD_DEVICE_KIND_PRINTER &&
+      cd_profile_get_filename (color_profile->profile) == NULL)
     {
       tooltip = _("Vendor supplied factory calibration data");
       goto out;
     }
 
   /* autogenerated profiles are crap */
-  if (cd_device_get_kind (priv->device) == CD_DEVICE_KIND_DISPLAY &&
-      cd_profile_get_kind (priv->profile) == CD_PROFILE_KIND_DISPLAY_DEVICE &&
-      !cd_profile_get_has_vcgt (priv->profile))
+  if (cd_device_get_kind (color_profile->device) == CD_DEVICE_KIND_DISPLAY &&
+      cd_profile_get_kind (color_profile->profile) == CD_PROFILE_KIND_DISPLAY_DEVICE &&
+      !cd_profile_get_has_vcgt (color_profile->profile))
     {
       tooltip = _("Full-screen display correction not possible with this profile");
       goto out;
     }
 
   /* greater than the calibration threshold for the device type */
-  num_days = cd_profile_get_age (priv->profile) / seconds_in_one_day;
-  if (cd_device_get_kind (priv->device) == CD_DEVICE_KIND_DISPLAY)
+  num_days = cd_profile_get_age (color_profile->profile) / seconds_in_one_day;
+  if (cd_device_get_kind (color_profile->device) == CD_DEVICE_KIND_DISPLAY)
     {
-      g_settings_get (priv->settings,
+      g_settings_get (color_profile->settings,
                       GCM_SETTINGS_RECALIBRATE_DISPLAY_THRESHOLD,
                       "u",
                       &threshold_days);
     }
-  else if (cd_device_get_kind (priv->device) == CD_DEVICE_KIND_DISPLAY)
+  else if (cd_device_get_kind (color_profile->device) == CD_DEVICE_KIND_DISPLAY)
     {
-      g_settings_get (priv->settings,
+      g_settings_get (color_profile->settings,
                       GCM_SETTINGS_RECALIBRATE_PRINTER_THRESHOLD,
                       "u",
                       &threshold_days);
@@ -232,59 +228,57 @@ out:
 static void
 cc_color_profile_refresh (CcColorProfile *color_profile)
 {
-  CcColorProfilePrivate *priv = color_profile->priv;
   const gchar *warnings;
-  gchar *title = NULL;
+  g_autofree gchar *title = NULL;
 
   /* show the image if the profile is default */
-  gtk_widget_set_visible (priv->widget_image, priv->is_default);
-  gtk_widget_set_margin_start (priv->widget_description,
-                              priv->is_default ? 0 : IMAGE_WIDGET_PADDING * 4);
+  gtk_widget_set_visible (color_profile->widget_image, color_profile->is_default);
+  gtk_widget_set_margin_start (color_profile->widget_description,
+                              color_profile->is_default ? 0 : IMAGE_WIDGET_PADDING * 4);
 
   /* set the title */
-  title = gcm_prefs_get_profile_title (priv->profile);
-  gtk_label_set_markup (GTK_LABEL (priv->widget_description), title);
-  g_free (title);
+  title = gcm_prefs_get_profile_title (color_profile->profile);
+  gtk_label_set_markup (GTK_LABEL (color_profile->widget_description), title);
 
   /* show any information */
   warnings = cc_color_profile_get_warnings (color_profile);
-  gtk_widget_set_visible (priv->widget_info, warnings != NULL);
-  gtk_widget_set_tooltip_text (priv->widget_info, warnings);
+  gtk_widget_set_visible (color_profile->widget_info, warnings != NULL);
+  gtk_widget_set_tooltip_text (color_profile->widget_info, warnings);
 }
 
 CdDevice *
 cc_color_profile_get_device (CcColorProfile *color_profile)
 {
   g_return_val_if_fail (CC_IS_COLOR_PROFILE (color_profile), NULL);
-  return color_profile->priv->device;
+  return color_profile->device;
 }
 
 CdProfile *
 cc_color_profile_get_profile (CcColorProfile *color_profile)
 {
   g_return_val_if_fail (CC_IS_COLOR_PROFILE (color_profile), NULL);
-  return color_profile->priv->profile;
+  return color_profile->profile;
 }
 
 const gchar *
 cc_color_profile_get_sortable (CcColorProfile *color_profile)
 {
   g_return_val_if_fail (CC_IS_COLOR_PROFILE (color_profile), NULL);
-  return color_profile->priv->sortable;
+  return color_profile->sortable;
 }
 
 gboolean
 cc_color_profile_get_is_default (CcColorProfile *color_profile)
 {
   g_return_val_if_fail (CC_IS_COLOR_PROFILE (color_profile), 0);
-  return color_profile->priv->is_default;
+  return color_profile->is_default;
 }
 
 void
 cc_color_profile_set_is_default (CcColorProfile *color_profile, gboolean is_default)
 {
   g_return_if_fail (CC_IS_COLOR_PROFILE (color_profile));
-  color_profile->priv->is_default = is_default;
+  color_profile->is_default = is_default;
   cc_color_profile_refresh (color_profile);
 }
 
@@ -296,13 +290,13 @@ cc_color_profile_get_property (GObject *object, guint param_id,
   switch (param_id)
     {
       case PROP_DEVICE:
-        g_value_set_object (value, color_profile->priv->device);
+        g_value_set_object (value, color_profile->device);
         break;
       case PROP_PROFILE:
-        g_value_set_object (value, color_profile->priv->profile);
+        g_value_set_object (value, color_profile->profile);
         break;
       case PROP_IS_DEFAULT:
-        g_value_set_boolean (value, color_profile->priv->is_default);
+        g_value_set_boolean (value, color_profile->is_default);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -319,13 +313,13 @@ cc_color_profile_set_property (GObject *object, guint param_id,
   switch (param_id)
     {
       case PROP_DEVICE:
-        color_profile->priv->device = g_value_dup_object (value);
+        color_profile->device = g_value_dup_object (value);
         break;
       case PROP_PROFILE:
-        color_profile->priv->profile = g_value_dup_object (value);
+        color_profile->profile = g_value_dup_object (value);
         break;
       case PROP_IS_DEFAULT:
-        color_profile->priv->is_default = g_value_get_boolean (value);
+        color_profile->is_default = g_value_get_boolean (value);
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -337,17 +331,16 @@ static void
 cc_color_profile_finalize (GObject *object)
 {
   CcColorProfile *color_profile = CC_COLOR_PROFILE (object);
-  CcColorProfilePrivate *priv = color_profile->priv;
 
-  if (priv->device_changed_id > 0)
-    g_signal_handler_disconnect (priv->device, priv->device_changed_id);
-  if (priv->profile_changed_id > 0)
-    g_signal_handler_disconnect (priv->profile, priv->profile_changed_id);
+  if (color_profile->device_changed_id > 0)
+    g_signal_handler_disconnect (color_profile->device, color_profile->device_changed_id);
+  if (color_profile->profile_changed_id > 0)
+    g_signal_handler_disconnect (color_profile->profile, color_profile->profile_changed_id);
 
-  g_free (priv->sortable);
-  g_object_unref (priv->device);
-  g_object_unref (priv->profile);
-  g_object_unref (priv->settings);
+  g_free (color_profile->sortable);
+  g_object_unref (color_profile->device);
+  g_object_unref (color_profile->profile);
+  g_object_unref (color_profile->settings);
 
   G_OBJECT_CLASS (cc_color_profile_parent_class)->finalize (object);
 }
@@ -356,17 +349,13 @@ static void
 cc_color_profile_changed_cb (CdDevice *device,
                              CcColorProfile *color_profile)
 {
-  CdProfile *profile;
-  CcColorProfilePrivate *priv = color_profile->priv;
+  g_autoptr(CdProfile) profile = NULL;
 
   /* check to see if the default has changed */
   profile = cd_device_get_default_profile (device);
   if (profile != NULL)
-    {
-      priv->is_default = g_strcmp0 (cd_profile_get_object_path (profile),
-                                    cd_profile_get_object_path (priv->profile)) == 0;
-      g_object_unref (profile);
-    }
+    color_profile->is_default = g_strcmp0 (cd_profile_get_object_path (profile),
+                                           cd_profile_get_object_path (color_profile->profile)) == 0;
   cc_color_profile_refresh (color_profile);
 }
 
@@ -390,17 +379,16 @@ static void
 cc_color_profile_constructed (GObject *object)
 {
   CcColorProfile *color_profile = CC_COLOR_PROFILE (object);
-  CcColorProfilePrivate *priv = color_profile->priv;
   const gchar *sortable_data_source;
-  gchar *sortable_device;
-  gchar *title;
+  g_autofree gchar *sortable_device = NULL;
+  g_autofree gchar *title = NULL;
 
   /* watch to see if the default changes */
-  priv->device_changed_id =
-    g_signal_connect (priv->device, "changed",
+  color_profile->device_changed_id =
+    g_signal_connect (color_profile->device, "changed",
                       G_CALLBACK (cc_color_profile_changed_cb), color_profile);
-  priv->profile_changed_id =
-    g_signal_connect (priv->profile, "changed",
+  color_profile->profile_changed_id =
+    g_signal_connect (color_profile->profile, "changed",
                       G_CALLBACK (cc_color_profile_changed_cb), color_profile);
 
   /* sort the profiles in the list by:
@@ -409,16 +397,14 @@ cc_color_profile_constructed (GObject *object)
    * 3. the date the profiles were created (newest first)
    * 4. the alpha sorting of the filename
    */
-  title = gcm_prefs_get_profile_title (priv->profile);
-  sortable_device = cc_color_device_get_sortable_base (priv->device);
-  sortable_data_source = cc_color_profile_get_profile_sort_data_source (priv->profile);
-  priv->sortable = g_strdup_printf ("%s-%s-%012" G_GINT64_FORMAT "-%s",
+  title = gcm_prefs_get_profile_title (color_profile->profile);
+  sortable_device = cc_color_device_get_sortable_base (color_profile->device);
+  sortable_data_source = cc_color_profile_get_profile_sort_data_source (color_profile->profile);
+  color_profile->sortable = g_strdup_printf ("%s-%s-%012" G_GINT64_FORMAT "-%s",
                                     sortable_device,
                                     sortable_data_source,
-                                    cd_profile_get_created (priv->profile),
+                                    cd_profile_get_created (color_profile->profile),
                                     title);
-  g_free (title);
-  g_free (sortable_device);
 
   cc_color_profile_refresh (color_profile);
 }
@@ -447,43 +433,36 @@ cc_color_profile_class_init (CcColorProfileClass *klass)
                                                          NULL,
                                                          FALSE,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-
-  g_type_class_add_private (klass, sizeof (CcColorProfilePrivate));
 }
 
 static void
 cc_color_profile_init (CcColorProfile *color_profile)
 {
-  CcColorProfilePrivate *priv;
   GtkWidget *box;
 
-  color_profile->priv = G_TYPE_INSTANCE_GET_PRIVATE (color_profile,
-                                                     CC_TYPE_COLOR_PROFILE,
-                                                     CcColorProfilePrivate);
-  priv = color_profile->priv;
-  priv->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
+  color_profile->settings = g_settings_new (GCM_SETTINGS_SCHEMA);
 
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 9);
 
   /* default tick */
-  priv->widget_image = gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
-  gtk_widget_set_margin_start (priv->widget_image, IMAGE_WIDGET_PADDING);
-  gtk_widget_set_margin_end (priv->widget_image, IMAGE_WIDGET_PADDING);
-  gtk_box_pack_start (GTK_BOX (box), priv->widget_image, FALSE, FALSE, 0);
+  color_profile->widget_image = gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_widget_set_margin_start (color_profile->widget_image, IMAGE_WIDGET_PADDING);
+  gtk_widget_set_margin_end (color_profile->widget_image, IMAGE_WIDGET_PADDING);
+  gtk_box_pack_start (GTK_BOX (box), color_profile->widget_image, FALSE, FALSE, 0);
 
   /* description */
-  priv->widget_description = gtk_label_new ("");
-  gtk_widget_set_margin_top (priv->widget_description, 9);
-  gtk_widget_set_margin_bottom (priv->widget_description, 9);
-  gtk_widget_set_halign (priv->widget_description, GTK_ALIGN_START);
-  gtk_box_pack_start (GTK_BOX (box), priv->widget_description, TRUE, TRUE, 0);
-  gtk_widget_show (priv->widget_description);
+  color_profile->widget_description = gtk_label_new ("");
+  gtk_widget_set_margin_top (color_profile->widget_description, 9);
+  gtk_widget_set_margin_bottom (color_profile->widget_description, 9);
+  gtk_widget_set_halign (color_profile->widget_description, GTK_ALIGN_START);
+  gtk_box_pack_start (GTK_BOX (box), color_profile->widget_description, TRUE, TRUE, 0);
+  gtk_widget_show (color_profile->widget_description);
 
   /* profile warnings/info */
-  priv->widget_info = gtk_image_new_from_icon_name ("dialog-information-symbolic", GTK_ICON_SIZE_MENU);
-  gtk_widget_set_margin_start (priv->widget_info, IMAGE_WIDGET_PADDING);
-  gtk_widget_set_margin_end (priv->widget_info, IMAGE_WIDGET_PADDING);
-  gtk_box_pack_start (GTK_BOX (box), priv->widget_info, FALSE, FALSE, 0);
+  color_profile->widget_info = gtk_image_new_from_icon_name ("dialog-information-symbolic", GTK_ICON_SIZE_MENU);
+  gtk_widget_set_margin_start (color_profile->widget_info, IMAGE_WIDGET_PADDING);
+  gtk_widget_set_margin_end (color_profile->widget_info, IMAGE_WIDGET_PADDING);
+  gtk_box_pack_start (GTK_BOX (box), color_profile->widget_info, FALSE, FALSE, 0);
 
   /* refresh */
   gtk_container_add (GTK_CONTAINER (color_profile), box);
