@@ -28,10 +28,7 @@
 #include "gsd-common-enums.h"
 #include "gnome-settings-bus.h"
 
-typedef struct _GsdDevicePrivate GsdDevicePrivate;
-typedef struct _GsdDeviceManagerPrivate GsdDeviceManagerPrivate;
-
-struct _GsdDevicePrivate
+typedef struct
 {
 	gchar *name;
 	gchar *device_file;
@@ -40,7 +37,9 @@ struct _GsdDevicePrivate
 	GsdDeviceType type;
 	guint width;
 	guint height;
-};
+} GsdDevicePrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (GsdDevice, gsd_device, G_TYPE_OBJECT)
 
 enum {
 	PROP_NAME = 1,
@@ -55,12 +54,12 @@ enum {
 enum {
 	DEVICE_ADDED,
 	DEVICE_REMOVED,
+	DEVICE_CHANGED,
 	N_SIGNALS
 };
 
 static guint signals[N_SIGNALS] = { 0 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GsdDevice, gsd_device, G_TYPE_OBJECT)
 G_DEFINE_TYPE (GsdDeviceManager, gsd_device_manager, G_TYPE_OBJECT)
 
 static void
@@ -246,6 +245,15 @@ gsd_device_manager_class_init (GsdDeviceManagerClass *klass)
 			      NULL, NULL, NULL,
 			      G_TYPE_NONE, 1,
 			      GSD_TYPE_DEVICE | G_SIGNAL_TYPE_STATIC_SCOPE);
+
+	signals[DEVICE_CHANGED] =
+		g_signal_new ("device-changed",
+			      GSD_TYPE_DEVICE_MANAGER,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GsdDeviceManagerClass, device_changed),
+			      NULL, NULL, NULL,
+			      G_TYPE_NONE, 1,
+			      GSD_TYPE_DEVICE | G_SIGNAL_TYPE_STATIC_SCOPE);
 }
 
 static void
@@ -325,9 +333,8 @@ GSettings *
 gsd_device_get_settings (GsdDevice *device)
 {
 	const gchar *schema = NULL, *vendor, *product;
-	GSettings *settings;
 	GsdDeviceType type;
-	gchar *path = NULL;
+	g_autofree gchar *path = NULL;
 
 	g_return_val_if_fail (GSD_IS_DEVICE (device), NULL);
 
@@ -354,13 +361,10 @@ gsd_device_get_settings (GsdDevice *device)
 	}
 
 	if (path) {
-		settings = g_settings_new_with_path (schema, path);
-		g_free (path);
+		return g_settings_new_with_path (schema, path);
 	} else {
-		settings = g_settings_new (schema);
+		return g_settings_new (schema);
 	}
-
-	return settings;
 }
 
 const gchar *
@@ -405,3 +409,19 @@ gsd_device_get_dimensions (GsdDevice *device,
 
 	return priv->width > 0 && priv->height > 0;
 }
+
+GsdDevice *
+gsd_device_manager_lookup_gdk_device (GsdDeviceManager *manager,
+				      GdkDevice	       *gdk_device)
+{
+	GsdDeviceManagerClass *klass;
+
+	g_return_val_if_fail (GSD_IS_DEVICE_MANAGER (manager), NULL);
+	g_return_val_if_fail (GDK_IS_DEVICE (gdk_device), NULL);
+
+	klass = GSD_DEVICE_MANAGER_GET_CLASS (manager);
+	if (!klass->lookup_device)
+		return NULL;
+
+	return klass->lookup_device (manager, gdk_device);
+}
