@@ -43,7 +43,7 @@ typedef struct {
 
 struct _CcKeyboardPanel
 {
-  CcPanel             parent;
+  CcPanel             parent_instance;
 
   /* Search */
   GtkWidget          *empty_search_placeholder;
@@ -109,28 +109,24 @@ transform_binding_to_accel (GBinding     *binding,
                             gpointer      user_data)
 {
   CcKeyboardItem *item;
+  CcKeyCombo *combo;
   gchar *accelerator;
 
   item = CC_KEYBOARD_ITEM (g_binding_get_source (binding));
+  combo = cc_keyboard_item_get_primary_combo (item);
 
   /* Embolden the label when the shortcut is modified */
   if (!cc_keyboard_item_is_value_default (item))
     {
-      gchar *tmp;
+      g_autofree gchar *tmp = NULL;
 
-      tmp = convert_keysym_state_to_string (item->keyval,
-                                            item->mask,
-                                            item->keycode);
+      tmp = convert_keysym_state_to_string (combo);
 
       accelerator = g_strdup_printf ("<b>%s</b>", tmp);
-
-      g_free (tmp);
     }
   else
     {
-      accelerator = convert_keysym_state_to_string (item->keyval,
-                                                    item->mask,
-                                                    item->keycode);
+      accelerator = convert_keysym_state_to_string (combo);
     }
 
   g_value_take_string (to_value, accelerator);
@@ -161,7 +157,7 @@ reset_all_shortcuts_cb (GtkWidget *widget,
   data = g_object_get_data (G_OBJECT (widget), "data");
 
   /* Don't reset custom shortcuts */
-  if (data->item->type == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
+  if (cc_keyboard_item_get_item_type (data->item) == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
     return;
 
   /* cc_keyboard_manager_reset_shortcut() already resets conflicting shortcuts,
@@ -240,7 +236,7 @@ add_item (CcKeyboardPanel *self,
                       NULL);
 
   /* Shortcut title */
-  label = gtk_label_new (item->description);
+  label = gtk_label_new (cc_keyboard_item_get_description (item));
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD_CHAR);
@@ -396,17 +392,18 @@ static gboolean
 search_match_shortcut (CcKeyboardItem *item,
                        const gchar    *search)
 {
+  CcKeyCombo *combo = cc_keyboard_item_get_primary_combo (item);
   GStrv shortcut_tokens, search_tokens;
   g_autofree gchar *normalized_accel = NULL;
   g_autofree gchar *accel = NULL;
   gboolean match;
   guint i;
 
-  if (is_empty_binding (item->keyval, item->mask, item->keycode))
+  if (is_empty_binding (combo))
     return FALSE;
 
   match = TRUE;
-  accel = convert_keysym_state_to_string (item->keyval, item->mask, item->keycode);
+  accel = convert_keysym_state_to_string (combo);
   normalized_accel = cc_util_normalize_casefold_and_unaccent (accel);
 
   shortcut_tokens = g_strsplit_set (normalized_accel, SHORTCUT_DELIMITERS, -1);
@@ -455,9 +452,9 @@ sort_function (GtkListBoxRow *a,
   b_data = g_object_get_data (G_OBJECT (b), "data");
 
   /* Put custom shortcuts below everything else */
-  if (a_data->item->type == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
+  if (cc_keyboard_item_get_item_type (a_data->item) == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
     return 1;
-  else if (b_data->item->type == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
+  else if (cc_keyboard_item_get_item_type (b_data->item) == CC_KEYBOARD_ITEM_TYPE_GSETTINGS_PATH)
     return -1;
 
   retval = g_strcmp0 (a_data->section_title, b_data->section_title);
@@ -465,7 +462,7 @@ sort_function (GtkListBoxRow *a,
   if (retval != 0)
     return retval;
 
-  return g_strcmp0 (a_data->item->description, b_data->item->description);
+  return g_strcmp0 (cc_keyboard_item_get_description (a_data->item), cc_keyboard_item_get_description (b_data->item));
 }
 
 static void
@@ -508,7 +505,7 @@ header_function (GtkListBoxRow *row,
   if (add_header)
     {
       GtkWidget *box, *label;
-      gchar *markup;
+      g_autofree gchar *markup = NULL;
 
       box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
       gtk_widget_set_margin_top (box, before ? 18 : 6);
@@ -529,8 +526,6 @@ header_function (GtkListBoxRow *row,
       gtk_list_box_row_set_header (row, box);
 
       gtk_widget_show_all (box);
-
-      g_free (markup);
     }
   else
     {
@@ -546,7 +541,10 @@ filter_function (GtkListBoxRow *row,
   CcKeyboardItem *item;
   RowData *data;
   gboolean retval;
-  gchar *search, *name;
+  g_autofree gchar *search = NULL;
+  g_autofree gchar *name = NULL;
+  g_auto(GStrv) terms = NULL;
+  guint i;
 
   if (gtk_entry_get_text_length (GTK_ENTRY (self->search_entry)) == 0)
     return TRUE;
@@ -557,13 +555,16 @@ filter_function (GtkListBoxRow *row,
 
   data = g_object_get_data (G_OBJECT (row), "data");
   item = data->item;
-  name = cc_util_normalize_casefold_and_unaccent (item->description);
+  name = cc_util_normalize_casefold_and_unaccent (cc_keyboard_item_get_description (item));
   search = cc_util_normalize_casefold_and_unaccent (gtk_entry_get_text (GTK_ENTRY (self->search_entry)));
+  terms = g_strsplit (search, " ", -1);
 
-  retval = strstr (name, search) != NULL || search_match_shortcut (item, search);
-
-  g_free (search);
-  g_free (name);
+  for (i = 0; terms && terms[i]; i++)
+    {
+      retval = strstr (name, terms[i]) || search_match_shortcut (item, terms[i]);
+      if (!retval)
+        break;
+    }
 
   return retval;
 }
@@ -709,9 +710,6 @@ cc_keyboard_panel_init (CcKeyboardPanel *self)
   /* Use a sizegroup to make the accelerator labels the same width */
   self->accelerator_sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
-  /* Shortcut editor dialog */
-  self->shortcut_editor = cc_keyboard_shortcut_editor_new (self->manager);
-
   g_signal_connect_swapped (self->manager,
                             "shortcut-added",
                             G_CALLBACK (add_item),
