@@ -422,11 +422,8 @@ update_jobs_list (PpJobsDialog *dialog)
 
   if (dialog->printer_name != NULL)
     {
-      if (dialog->get_jobs_cancellable != NULL)
-        {
-          g_cancellable_cancel (dialog->get_jobs_cancellable);
-          g_clear_object (&dialog->get_jobs_cancellable);
-        }
+      g_cancellable_cancel (dialog->get_jobs_cancellable);
+      g_clear_object (&dialog->get_jobs_cancellable);
 
       dialog->get_jobs_cancellable = g_cancellable_new ();
 
@@ -664,11 +661,8 @@ pp_jobs_dialog_set_callback (PpJobsDialog         *dialog,
 void
 pp_jobs_dialog_free (PpJobsDialog *dialog)
 {
-  if (dialog->get_jobs_cancellable != NULL)
-    {
-      g_cancellable_cancel (dialog->get_jobs_cancellable);
-      g_clear_object (&dialog->get_jobs_cancellable);
-    }
+  g_cancellable_cancel (dialog->get_jobs_cancellable);
+  g_clear_object (&dialog->get_jobs_cancellable);
 
   gtk_widget_destroy (GTK_WIDGET (dialog->dialog));
   dialog->dialog = NULL;
