@@ -219,7 +219,7 @@ got_the_client (GObject      *source,
                 GAsyncResult *res,
                 gpointer      user_data)
 {
-  g_autoptr(GError) error = NULL;
+  GError *error = NULL;
   GTask *task = user_data;
   GObject *obj;
 
@@ -227,6 +227,7 @@ got_the_client (GObject      *source,
 
   if (obj == NULL)
     {
+      /* error ownership gets transferred to the task */
       g_task_return_error (task, error);
       return;
     }
@@ -240,7 +241,7 @@ got_the_bus (GObject      *source,
              GAsyncResult *res,
              gpointer      user_data)
 {
-  g_autoptr(GError) error = NULL;
+  GError *error = NULL;
   GTask *task = user_data;
   GCancellable *cancellable;
   GDBusConnection *bus;
@@ -249,6 +250,7 @@ got_the_bus (GObject      *source,
   if (bus == NULL)
     {
       g_prefix_error (&error, "could not connect to D-Bus: ");
+      /* error ownership gets transferred to the task */
       g_task_return_error (task, error);
       return;
     }
