@@ -18,8 +18,7 @@
  * Written by: Matthias Clasen <mclasen@redhat.com>
  */
 
-#ifndef __UM_UTILS_H__
-#define __UM_UTILS_H__
+#pragma once
 
 #include <gtk/gtk.h>
 #include <act/act.h>
@@ -59,13 +58,6 @@ void     rounded_rectangle                (cairo_t     *cr,
                                            gdouble      width,
                                            gdouble      height);
 
-void     down_arrow                       (GtkStyleContext *context,
-                                           cairo_t         *cr,
-                                           gint             x,
-                                           gint             y,
-                                           gint             width,
-                                           gint             height);
-
 gboolean is_valid_name                    (const gchar     *name);
 gboolean is_valid_username                (const gchar     *name,
                                            gchar          **tip);
@@ -73,8 +65,6 @@ gboolean is_valid_username                (const gchar     *name,
 void     generate_username_choices        (const gchar     *name,
                                            GtkListStore    *store);
 
-gchar *  get_smart_date                   (GDateTime *date);
-
 cairo_surface_t *render_user_icon         (ActUser         *user,
                                            UmIconStyle      style,
                                            gint             icon_size,
@@ -86,5 +76,3 @@ void     set_user_icon_data               (ActUser         *user,
 gboolean would_demote_only_admin          (ActUser *user);
 
 G_END_DECLS
-
-#endif
