@@ -39,6 +39,8 @@ struct _CcApplication
 {
   GtkApplication  parent;
 
+  CcShellModel   *model;
+
   CcWindow       *window;
 };
 
@@ -59,7 +61,6 @@ G_DEFINE_TYPE (CcApplication, cc_application, GTK_TYPE_APPLICATION)
 const GOptionEntry all_options[] = {
   { "version", 0, 0, G_OPTION_ARG_NONE, NULL, N_("Display version number"), NULL },
   { "verbose", 'v', 0, G_OPTION_ARG_NONE, NULL, N_("Enable verbose mode"), NULL },
-  { "overview", 'o', 0, G_OPTION_ARG_NONE, NULL, N_("Show the overview"), NULL },
   { "search", 's', 0, G_OPTION_ARG_STRING, NULL, N_("Search for the string"), "SEARCH" },
   { "list", 'l', 0, G_OPTION_ARG_NONE, NULL, N_("List possible panel names and exit"), NULL },
   { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Panel to display"), N_("[PANEL] [ARGUMENT…]") },
@@ -168,10 +169,6 @@ cc_application_command_line (GApplication            *application,
     {
       cc_window_set_search_item (self->window, search_str);
     }
-  else if (g_variant_dict_contains (options, "overview"))
-    {
-      cc_window_set_overview_page (self->window);
-    }
   else if (g_variant_dict_lookup (options, G_OPTION_REMAINING, "^a&ay", &start_panels))
     {
       const char *start_id;
@@ -264,7 +261,8 @@ cc_application_startup (GApplication *application)
   gtk_application_set_accels_for_action (GTK_APPLICATION (application),
                                          "app.help", help_accels);
 
-  self->window = cc_window_new (GTK_APPLICATION (application));
+  self->model = cc_shell_model_new ();
+  self->window = cc_window_new (GTK_APPLICATION (application), self->model);
 }
 
 static void
@@ -325,3 +323,11 @@ cc_application_new (void)
                        "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
                        NULL);
 }
+
+CcShellModel *
+cc_application_get_model (CcApplication *self)
+{
+  g_return_val_if_fail (CC_IS_APPLICATION (self), NULL);
+
+  return self->model;
+}
