@@ -60,11 +60,16 @@ void                 cc_panel_list_add_panel                     (CcPanelList
                                                                   const gchar        *title,
                                                                   const gchar        *description,
                                                                   gchar             **keywords,
-                                                                  const gchar        *icon);
+                                                                  const gchar        *icon,
+                                                                  CcPanelVisibility   visibility);
 
 void                 cc_panel_list_set_active_panel               (CcPanelList       *self,
                                                                    const gchar       *id);
 
+void                 cc_panel_list_set_panel_visibility          (CcPanelList        *self,
+                                                                  const gchar        *id,
+                                                                  CcPanelVisibility   visibility);
+
 G_END_DECLS
 
 #endif /* CC_PANEL_LIST_H */
